;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "russian-techwriter" "20251010.538"
  "Input methods for Russian technical writers."
  ()
  :url "https://github.com/dunmaksim/emacs-russian-techwriter-input-method"
  :commit "a568c8a3f409f7f9b5cb12143f277af78fef9a26"
  :revdesc "a568c8a3f409"
  :keywords '("multilingual" "input method" "cyrillic" "i18n")
  :authors '(("Maxim Dunaevskii" . "dunmaksim@yandex.ru")))
